require "iconv/iconv.so"
require "iconv/version"

class Iconv
  # Your code goes here...
end
